Attention is currently required from: Felix Held, Fred Reitberger, Jason Glenesk, Matt DeVillier.
Patrick Rudolph has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/86582?usp=email )
Change subject: soc/amd/common/block/lpc: Limit ROM2 to 16MiB
......................................................................
soc/amd/common/block/lpc: Limit ROM2 to 16MiB
Don't map more than 16MiB when the SPI ROM size is bigger than 16MiB.
Change-Id: Ie811f6a38363f2e900611b3f3f407a94d8137c89
Signed-off-by: Patrick Rudolph <patrick.rudolph(a)9elements.com>
---
M src/soc/amd/common/block/lpc/lpc_util.c
1 file changed, 4 insertions(+), 1 deletion(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/82/86582/1
diff --git a/src/soc/amd/common/block/lpc/lpc_util.c b/src/soc/amd/common/block/lpc/lpc_util.c
index 309825a..6e4ddcb 100644
--- a/src/soc/amd/common/block/lpc/lpc_util.c
+++ b/src/soc/amd/common/block/lpc/lpc_util.c
@@ -277,8 +277,11 @@
* 0xffe0(0000): 2MB
* 0xffc0(0000): 4MB
*/
- pci_write_config16(_LPCB_DEV, ROM_ADDRESS_RANGE2_START, 0x10000
+ if (CONFIG_COREBOOT_ROMSIZE_KB <= 16384)
+ pci_write_config16(_LPCB_DEV, ROM_ADDRESS_RANGE2_START, 0x10000
- (CONFIG_COREBOOT_ROMSIZE_KB >> 6));
+ else
+ pci_write_config16(_LPCB_DEV, ROM_ADDRESS_RANGE2_START, 0xff00);
/* Enable LPC ROM range end at 0xffff(ffff). */
pci_write_config16(_LPCB_DEV, ROM_ADDRESS_RANGE2_END, 0xffff);
--
To view, visit https://review.coreboot.org/c/coreboot/+/86582?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Ie811f6a38363f2e900611b3f3f407a94d8137c89
Gerrit-Change-Number: 86582
Gerrit-PatchSet: 1
Gerrit-Owner: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Reviewer: Felix Held <felix-coreboot(a)felixheld.de>
Gerrit-Reviewer: Fred Reitberger <reitbergerfred(a)gmail.com>
Gerrit-Reviewer: Jason Glenesk <jason.glenesk(a)gmail.com>
Gerrit-Reviewer: Matt DeVillier <matt.devillier(a)amd.corp-partner.google.com>
Gerrit-Attention: Jason Glenesk <jason.glenesk(a)gmail.com>
Gerrit-Attention: Matt DeVillier <matt.devillier(a)amd.corp-partner.google.com>
Gerrit-Attention: Fred Reitberger <reitbergerfred(a)gmail.com>
Gerrit-Attention: Felix Held <felix-coreboot(a)felixheld.de>
Patrick Rudolph has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/86581?usp=email )
Change subject: soc/amd/glinda: Enable x86_64 support
......................................................................
soc/amd/glinda: Enable x86_64 support
The code compiles and works fine in x86_64. Thus allow the user
to use x86_64.
TEST: Booted on amd/birman+ to OS using EDK2 as payload.
Change-Id: If1b5d91a376770c0f0e1a4ee46dd625b401fbfa6
Signed-off-by: Patrick Rudolph <patrick.rudolph(a)9elements.com>
---
M src/soc/amd/glinda/Kconfig
1 file changed, 1 insertion(+), 0 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/81/86581/1
diff --git a/src/soc/amd/glinda/Kconfig b/src/soc/amd/glinda/Kconfig
index 39fb785..70bdb69 100644
--- a/src/soc/amd/glinda/Kconfig
+++ b/src/soc/amd/glinda/Kconfig
@@ -90,6 +90,7 @@
select VBOOT_DEFINE_WIDEVINE_COUNTERS if VBOOT_STARTS_BEFORE_BOOTBLOCK
select X86_AMD_FIXED_MTRRS
select X86_INIT_NEED_1_SIPI
+ select HAVE_X86_64_SUPPORT
help
AMD Glinda support
--
To view, visit https://review.coreboot.org/c/coreboot/+/86581?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: If1b5d91a376770c0f0e1a4ee46dd625b401fbfa6
Gerrit-Change-Number: 86581
Gerrit-PatchSet: 1
Gerrit-Owner: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Attention is currently required from: Jérémy Compostella.
Patrick Rudolph has uploaded this change for review. ( https://review.coreboot.org/c/coreboot/+/86580?usp=email )
Change subject: cpu/x86/64bit: Allow to map more of the address space
......................................................................
cpu/x86/64bit: Allow to map more of the address space
On AMD platforms the SPI flash can be accessed using the ROM3
mapping in upper MMIO space. To reach the MMIO window the default
page tables must be extended to cover the address by default.
Add support for a SoC specific default address space being used on
x86_64, where the default of 4GiB/512GiB remains.
The size can be specified by the Kconfig CPU_PT_ROM_MAP_GB option.
Used in the following patch to use ROM3 mapping on AMD platforms.
TEST: Access ROM3 bar at 0xfd00000000 on amd/birman+
Change-Id: If669426f2b5ae40dd5c62e17f3a0234783b7d462
Signed-off-by: Patrick Rudolph <patrick.rudolph(a)9elements.com>
---
M src/cpu/x86/64bit/pt.S
M src/cpu/x86/64bit/pt1G.S
M src/cpu/x86/Kconfig
3 files changed, 19 insertions(+), 6 deletions(-)
git pull ssh://review.coreboot.org:29418/coreboot refs/changes/80/86580/1
diff --git a/src/cpu/x86/64bit/pt.S b/src/cpu/x86/64bit/pt.S
index 4b2f3c8..55d3ed0 100644
--- a/src/cpu/x86/64bit/pt.S
+++ b/src/cpu/x86/64bit/pt.S
@@ -20,16 +20,18 @@
.global PM4LE
.align 4096
PM4LE:
-.quad _GEN_DIR(PDPT)
+.rept (CONFIG_CPU_PT_ROM_MAP_GB + 511) / 512
+.quad _GEN_DIR(PDPT + 4096 * ((. - PM4LE) >> 3))
+.endr
.align 4096
PDT: /* identity map 2MiB pages */
-.rept 2048
+.rept 512 * CONFIG_CPU_PT_ROM_MAP_GB
.quad _GEN_PAGE(0x200000 * ((. - PDT) >> 3))
.endr
.align 4096
PDPT: /* Point to PDT */
-.rept 4
+.rept CONFIG_CPU_PT_ROM_MAP_GB
.quad _GEN_DIR(PDT + 4096 * ((. - PDPT) >> 3))
.endr
diff --git a/src/cpu/x86/Kconfig b/src/cpu/x86/Kconfig
index 828c0f9..ae94f62 100644
--- a/src/cpu/x86/Kconfig
+++ b/src/cpu/x86/Kconfig
@@ -159,6 +159,15 @@
Select this option from boards/SoCs that do not support the Page1GB
CPUID feature (CPUID.80000001H:EDX.bit26).
+config CPU_PT_ROM_MAP_GB
+ int
+ default 4 if NEED_SMALL_2MB_PAGE_TABLES
+ default 512 if !NEED_SMALL_2MB_PAGE_TABLES
+ help
+ GiB of the lower address space to identity map when using x86_64
+ page tables in ROM. Higher values require more space in SPI flash.
+ SoC can overwrite the value if necessary.
+
config SMM_ASEG
bool
default n
diff --git a/src/cpu/x86/64bit/pt1G.S b/src/cpu/x86/64bit/pt1G.S
index 3502964..3a0e4b5 100644
--- a/src/cpu/x86/64bit/pt1G.S
+++ b/src/cpu/x86/64bit/pt1G.S
@@ -20,10 +20,12 @@
.global PM4LE
.align 4096
PM4LE:
-.quad _GEN_DIR(PDPT)
+.rept (CONFIG_CPU_PT_ROM_MAP_GB + 511) / 512
+.quad _GEN_DIR(PDPT + 4096 * ((. - PM4LE) >> 3))
+.endr
.align 4096
-PDPT: /* identity map 1GiB pages * 512 */
-.rept 512
+PDPT: /* identity map 1GiB pages * CONFIG_CPU_PT_ROM_MAP_GB */
+.rept CONFIG_CPU_PT_ROM_MAP_GB
.quad _GEN_PAGE(0x40000000 * ((. - PDPT) >> 3))
.endr
--
To view, visit https://review.coreboot.org/c/coreboot/+/86580?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: newchange
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: If669426f2b5ae40dd5c62e17f3a0234783b7d462
Gerrit-Change-Number: 86580
Gerrit-PatchSet: 1
Gerrit-Owner: Patrick Rudolph <patrick.rudolph(a)9elements.com>
Gerrit-Reviewer: Jérémy Compostella <jeremy.compostella(a)intel.com>
Gerrit-Attention: Jérémy Compostella <jeremy.compostella(a)intel.com>
Attention is currently required from: Dinesh Gehlot, Eric Lai, Jayvik Desai, Kapil Porwal, Nick Vaccaro.
Subrata Banik has posted comments on this change by Kapil Porwal. ( https://review.coreboot.org/c/coreboot/+/86579?usp=email )
Change subject: mb/google/trulo: Lock GPIO pad configuration for GPP_F17
......................................................................
Patch Set 1: Code-Review+2
--
To view, visit https://review.coreboot.org/c/coreboot/+/86579?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: I9211ac70539d251746332448691d22b454bc6a2b
Gerrit-Change-Number: 86579
Gerrit-PatchSet: 1
Gerrit-Owner: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Reviewer: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Reviewer: Eric Lai <ericllai(a)google.com>
Gerrit-Reviewer: Jayvik Desai <jayvik(a)google.com>
Gerrit-Reviewer: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Reviewer: Subrata Banik <subratabanik(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Jayvik Desai <jayvik(a)google.com>
Gerrit-Attention: Eric Lai <ericllai(a)google.com>
Gerrit-Attention: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Attention: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Attention: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Comment-Date: Mon, 24 Feb 2025 09:05:34 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: Yes
Attention is currently required from: Dinesh Gehlot, Eric Lai, Jayvik Desai, Kapil Porwal, Nick Vaccaro, Qinghong Zeng, Subrata Banik.
hualin wei has posted comments on this change by hualin wei. ( https://review.coreboot.org/c/coreboot/+/86510?usp=email )
Change subject: mb/google/nissa/var/pujjoniru: Modify the gpio of GPIO_PCH_WP
......................................................................
Patch Set 4:
This change is ready for review.
--
To view, visit https://review.coreboot.org/c/coreboot/+/86510?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Iee76fa8b357aa472699f17789b2c718028f812a3
Gerrit-Change-Number: 86510
Gerrit-PatchSet: 4
Gerrit-Owner: hualin wei <weihualin(a)huaqin.corp-partner.google.com>
Gerrit-Reviewer: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Reviewer: Eric Lai <ericllai(a)google.com>
Gerrit-Reviewer: Jayvik Desai <jayvik(a)google.com>
Gerrit-Reviewer: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Reviewer: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Reviewer: Qinghong Zeng <zengqinghong(a)huaqin.corp-partner.google.com>
Gerrit-Reviewer: Subrata Banik <subratabanik(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-CC: Cindy Lu <luyi8(a)huaqin.corp-partner.google.com>
Gerrit-CC: Dolan Liu <liuyong5(a)huaqin.corp-partner.google.com>
Gerrit-Attention: Jayvik Desai <jayvik(a)google.com>
Gerrit-Attention: Eric Lai <ericllai(a)google.com>
Gerrit-Attention: Subrata Banik <subratabanik(a)google.com>
Gerrit-Attention: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Attention: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Attention: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Attention: Qinghong Zeng <zengqinghong(a)huaqin.corp-partner.google.com>
Gerrit-Comment-Date: Mon, 24 Feb 2025 08:46:49 +0000
Gerrit-HasComments: No
Gerrit-Has-Labels: No
Attention is currently required from: Dinesh Gehlot, Eric Lai, Jayvik Desai, Nick Vaccaro, Subrata Banik.
Kapil Porwal has posted comments on this change by Kapil Porwal. ( https://review.coreboot.org/c/coreboot/+/86555?usp=email )
Change subject: mb/google/trulo: Update GPIO wake pins
......................................................................
Patch Set 3:
(2 comments)
File src/mainboard/google/brya/variants/trulo/gpio.c:
https://review.coreboot.org/c/coreboot/+/86555/comment/85c7a363_149704ef?us… :
PS2, Line 61: PAD_CFG_GPI_APIC
> this is now getting register as IOAPIC and not like shared interrupt in existing implementation […]
Acknowledged
Previously: IRQ9 + GPE0_DW1_03
Now: IRQ27
https://review.coreboot.org/c/coreboot/+/86555/comment/9a4edd3b_e533a047?us… :
PS2, Line 245: PAD_CFG_GPI_IRQ_WAKE_LOCK(GPP_F17, NONE, EDGE_SINGLE, INVERT, LOCK_CONFIG),
> this should move into a separate CL as you are locking down the EC wake PIN
Acknowledged
--
To view, visit https://review.coreboot.org/c/coreboot/+/86555?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: I055a60476e4a37bf74940802157bb9cd30bac3c4
Gerrit-Change-Number: 86555
Gerrit-PatchSet: 3
Gerrit-Owner: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Reviewer: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Reviewer: Eric Lai <ericllai(a)google.com>
Gerrit-Reviewer: Jayvik Desai <jayvik(a)google.com>
Gerrit-Reviewer: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Reviewer: Subrata Banik <subratabanik(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-Attention: Jayvik Desai <jayvik(a)google.com>
Gerrit-Attention: Eric Lai <ericllai(a)google.com>
Gerrit-Attention: Subrata Banik <subratabanik(a)google.com>
Gerrit-Attention: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Attention: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Comment-Date: Mon, 24 Feb 2025 08:44:08 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No
Comment-In-Reply-To: Subrata Banik <subratabanik(a)google.com>
Attention is currently required from: Dinesh Gehlot, Eric Lai, Jayvik Desai, Kapil Porwal, Nick Vaccaro, Paul Menzel, Subrata Banik.
SH Kim has posted comments on this change by SH Kim. ( https://review.coreboot.org/c/coreboot/+/86377?usp=email )
Change subject: mb/google/nissa/var/meliks: Copy pirrha’s overridetree as initial one
......................................................................
Patch Set 8:
(1 comment)
Patchset:
PS8:
Ready for review.
--
To view, visit https://review.coreboot.org/c/coreboot/+/86377?usp=email
To unsubscribe, or for help writing mail filters, visit https://review.coreboot.org/settings?usp=email
Gerrit-MessageType: comment
Gerrit-Project: coreboot
Gerrit-Branch: main
Gerrit-Change-Id: Ifd6dfbeca7276dbacd72f9145ed7119566c8faef
Gerrit-Change-Number: 86377
Gerrit-PatchSet: 8
Gerrit-Owner: SH Kim <sh_.kim(a)samsung.corp-partner.google.com>
Gerrit-Reviewer: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Reviewer: Eric Lai <ericllai(a)google.com>
Gerrit-Reviewer: Jayvik Desai <jayvik(a)google.com>
Gerrit-Reviewer: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Reviewer: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Reviewer: Subrata Banik <subratabanik(a)google.com>
Gerrit-Reviewer: build bot (Jenkins) <no-reply(a)coreboot.org>
Gerrit-CC: Paul Menzel <paulepanter(a)mailbox.org>
Gerrit-Attention: Jayvik Desai <jayvik(a)google.com>
Gerrit-Attention: Eric Lai <ericllai(a)google.com>
Gerrit-Attention: Subrata Banik <subratabanik(a)google.com>
Gerrit-Attention: Kapil Porwal <kapilporwal(a)google.com>
Gerrit-Attention: Paul Menzel <paulepanter(a)mailbox.org>
Gerrit-Attention: Dinesh Gehlot <digehlot(a)google.com>
Gerrit-Attention: Nick Vaccaro <nvaccaro(a)chromium.org>
Gerrit-Comment-Date: Mon, 24 Feb 2025 08:43:50 +0000
Gerrit-HasComments: Yes
Gerrit-Has-Labels: No